﻿using System;
using System.Collections.Generic;
using System.Text;
using System.IO.Ports;

namespace IRcmd
{
    class Program
    {
        static void Main(string[] args)
        {
            if (args.Length != 2)
            {
                string [] ports = SerialPort.GetPortNames();
                Console.WriteLine("Usage: ircmd [port] [irpacket-file]");
                Console.WriteLine("Follow ports are available on your system:");
                foreach( string s in ports ) Console.WriteLine(s);                                
                return;
            }
            
            try
            {
                SerialPort sp = new SerialPort(args[0], 19200, Parity.None, 8, StopBits.One);
                sp.Open();

                // パケットのロード
                IRPacket[] irps = IRPacket.load(args[1]);
                System.Array.Reverse(irps);
                
                // シールドの作成
                IRShield irs = new IRShield(sp);

                foreach( IRPacket irp in irps ) 
                {
                    Console.WriteLine("\r\n"+irp.ToString());
                    if ( irs.send(irp, true) < 0 )
                    { 
                        Console.WriteLine("=>Error");
                    }
                    else
                    {
                        Console.WriteLine("=>Ack");
                    }
                }

                // クローズ
                sp.Close();
            }
            catch (Exception e)
            {
                Console.Error.Write("Cannot open the port " + args[0] + e.ToString());
                return;
            }
        }
    }
}
